import pygame
import random
import time

# 초기화
pygame.init()

# 화면 설정
width = 800
height = 600
screen = pygame.display.set_mode((width, height))
pygame.display.set_caption("벽돌깨기 게임")

# 색상
WHITE = (255, 255, 255)
BLACK = (0, 0, 0)
RED = (255, 0, 0)
BLUE = (0, 0, 255)
GREEN = (0, 255, 0)

# 폰트 설정
font = pygame.font.Font(None, 36)

# 게임 변수
lives = 3
game_over = False
level = 1
initial_ball_speed = 3

def init_game():
    global paddle, ball, ball_speed_x, ball_speed_y, bricks, lives, game_over, level, speed_multiplier
    
    # 패들 설정
    paddle_width = 100
    paddle_height = 10
    paddle = pygame.Rect(width//2 - paddle_width//2, height - 20, paddle_width, paddle_height)

    # 공 설정
    ball_size = 10
    ball = pygame.Rect(width//2 - ball_size//2, height//2 - ball_size//2, ball_size, ball_size)
    ball_speed_x = initial_ball_speed * (level ** 0.5)  # 레벨에 따라 속도 증가
    ball_speed_y = -initial_ball_speed * (level ** 0.5)

    # 벽돌 설정
    brick_width = 80
    brick_height = 30
    bricks = []
    for i in range(8):
        for j in range(5):
            brick = pygame.Rect(i * (brick_width + 5) + 30, j * (brick_height + 5) + 30, brick_width, brick_height)
            bricks.append(brick)

    lives = 3
    game_over = False
    speed_multiplier = 1.0

def reset_ball():
    ball.center = (width // 2, height // 2)
    return initial_ball_speed * (level ** 0.5), -initial_ball_speed * (level ** 0.5)

def draw_lives():
    lives_text = font.render(f"Lives: {lives}", True, WHITE)
    screen.blit(lives_text, (10, 10))

def draw_level():
    level_text = font.render(f"Level: {level}", True, WHITE)
    screen.blit(level_text, (width - 100, 10))

def show_message(message, color):
    text = font.render(message, True, color)
    screen.blit(text, (width//2 - text.get_width()//2, height//2 - text.get_height()//2))
    pygame.display.flip()
    pygame.time.wait(2000)  # 2초 동안 메시지 표시

init_game()

# 게임 루프
clock = pygame.time.Clock()
running = True

while running:
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            running = False

    if not game_over:
        # 패들 이동
        keys = pygame.key.get_pressed()
        if keys[pygame.K_LEFT] and paddle.left > 0:
            paddle.x -= 5
        if keys[pygame.K_RIGHT] and paddle.right < width:
            paddle.x += 5

        # 공 이동
        ball.x += ball_speed_x
        ball.y += ball_speed_y

        # 벽 충돌 체크
        if ball.left <= 0 or ball.right >= width:
            ball_speed_x = -ball_speed_x
        if ball.top <= 0:
            ball_speed_y = -ball_speed_y

        # 패들 충돌 체크
        if ball.colliderect(paddle) and ball_speed_y > 0:
            ball_speed_y = -ball_speed_y
            ball_speed_x += random.randint(-1, 1)

        # 벽돌 충돌 체크
        for brick in bricks[:]:
            if ball.colliderect(brick):
                bricks.remove(brick)
                ball_speed_y = -ball_speed_y
                break

        # 아웃 체크
        if ball.bottom >= height:
            lives -= 1
            if lives > 0:
                ball_speed_x, ball_speed_y = reset_ball()
            else:
                game_over = True

        # 모든 벽돌을 부쉈는지 체크
        if not bricks:
            show_message("축하합니다!", GREEN)
            level += 1
            init_game()

        # 화면 그리기
        screen.fill(BLACK)
        pygame.draw.rect(screen, BLUE, paddle)
        pygame.draw.ellipse(screen, WHITE, ball)
        for brick in bricks:
            pygame.draw.rect(screen, RED, brick)
        draw_lives()
        draw_level()

        pygame.display.flip()
    else:
        show_message("GAME OVER", RED)
        running = False

    clock.tick(60)

pygame.quit()